@@ -315,8 +315,6 @@ class Diagram(DiagramMultiContainer):
             list(items),
             {
                 "class": DIAGRAM_CLASS,
-                "xmlns": "http://www.w3.org/2000/svg",
-                "xmlns:xlink": "http://www.w3.org/1999/xlink",
             },
         )
         self.type = kwargs.get("type", "simple")
@@ -324,7 +322,6 @@ class Diagram(DiagramMultiContainer):
             self.items.insert(0, Start(self.type))
         if items and not isinstance(items[-1], End):
             self.items.append(End(self.type))
-        self.css: Opt[str] = kwargs.get("css", DEFAULT_STYLE)
         self.up = 0
         self.down = 0
         self.height = 0
@@ -345,8 +342,6 @@ class Diagram(DiagramMultiContainer):
     def __repr__(self) -> str:
         items = ", ".join(map(repr, self.items[1:-1]))
         pieces = [] if not items else [items]
-        if self.css != DEFAULT_STYLE:
-            pieces.append(f"css={repr(self.css)}")
         if self.type != "simple":
             pieces.append(f"type={repr(self.type)}")
         return f'Diagram({", ".join(pieces)})'
@@ -358,8 +353,6 @@ class Diagram(DiagramMultiContainer):
         paddingBottom: Opt[float] = None,
         paddingLeft: Opt[float] = None,
     ) -> Diagram:
-        if self.css:
-            Style(self.css).addTo(self)
         if paddingRight is None:
             paddingRight = paddingTop
         if paddingBottom is None:
@@ -398,6 +391,20 @@ class Diagram(DiagramMultiContainer):
             self.format()
         return DiagramItem.writeSvg(self, write)
 
+    def writeStandalone(self, write: WriterF, css: str|None = None) -> None:
+        if not self.formatted:
+            self.format()
+        if css is None:
+            css = DEFAULT_STYLE
+        Style(css).addTo(self)
+        self.attrs["xmlns"] = "http://www.w3.org/2000/svg"
+        self.attrs['xmlns:xlink'] = "http://www.w3.org/1999/xlink"
+        result = DiagramItem.writeSVG(self, write)
+        self.children.pop()
+        del self.attrs["xmlns"]
+        del self.attrs["xmlns:xlink"]
+        return result
+
 
 class Sequence(DiagramMultiContainer):
     def __init__(self, *items: Node):
